@@ -187,6 +187,8 @@ def channel_name(url: str) -> str:
 
     - :samp:`https://youtube.com/c/{channel_name}/*`
     - :samp:`https://youtube.com/channel/{channel_id}/*
+    - :samp:`https://youtube.com/u/{channel_name}/*`
+    - :samp:`https://youtube.com/user/{channel_id}/*
 
     :param str url:
         A YouTube url containing a channel name.
@@ -196,7 +198,9 @@ def channel_name(url: str) -> str:
     """
     patterns = [
         r"(?:\/(c)\/([\d\w_\-]+)(\/.*)?)",
-        r"(?:\/(channel)\/([\w\d_\-]+)(\/.*)?)"
+        r"(?:\/(channel)\/([\w\d_\-]+)(\/.*)?)",
+        r"(?:\/(u)\/([\d\w_\-]+)(\/.*)?)",
+        r"(?:\/(user)\/([\w\d_\-]+)(\/.*)?)"
     ]
     for pattern in patterns:
         regex = re.compile(pattern)
@@ -231,6 +235,8 @@ def video_info_url(video_id: str, watch_url: str) -> str:
             ("eurl", quote(watch_url)),
             ("hl", "en_US"),
             ("html5", "1"),
+            ("c", "TVHTML5"),
+            ("cver", "7.20201028"),
         ]
     )
     return _video_info_url(params)
@@ -261,6 +267,8 @@ def video_info_url_age_restricted(video_id: str, embed_html: str) -> str:
             ("eurl", eurl),
             ("sts", sts),
             ("html5", "1"),
+            ("c", "TVHTML5"),
+            ("cver", "7.20201028"),
         ]
     )
     return _video_info_url(params)
